@@ -1,10 +1,12 @@
+from typing import Optional
+
 from pydantic import BaseModel
 
 
 class ProjectUpdateRequest(BaseModel):
     project_id: str
-    name: str = ""
-    description: str = ""
+    name: Optional[str]
+    description: Optional[str]
 
     @property
     def endpoint(self):
