@@ -1,6 +1,6 @@
 """This module contains the response models for the detected issues endpoint
 and a report helper."""
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel, Field
 
@@ -9,9 +9,9 @@ from mythx_models.response.issue import Issue, SourceFormat, SourceType
 
 class IssueReport(BaseModel):
     issues: List[Issue]
-    source_type: SourceType = Field(alias="sourceType")
-    source_format: SourceFormat = Field(alias="sourceFormat")
-    source_list: List[str] = Field(alias="sourceList")
+    source_type: Optional[SourceType] = Field(alias="sourceType")
+    source_format: Optional[SourceFormat] = Field(alias="sourceFormat")
+    source_list: Optional[List[str]] = Field(alias="sourceList")
     meta_data: Dict[str, Any] = Field(alias="meta")
 
 
